@@ -1,8 +1,5 @@
-##  $Id: Config.pm.in 9567 2013-11-17 20:24:35Z iulius $
-##
 ##  Perl module which sets up any and all variables that an
 ##  INN Perl script might need.
-##
 
 package INN::Config;
 
@@ -10,31 +7,28 @@ use warnings;
 use Exporter;
 
 our @ISA = qw(Exporter);
-our $VERSION = '2.6.1';
-
+our $VERSION = '2.7.1';
 
 ##  First, two necessary variables (listed below in @DIRVAR).
 our $prefix = '/usr';
 our $exec_prefix = "${prefix}";
 
-
 ##  Then, process the variables provided by innconfval.
 my @INNCONFVAR = ();
 my @values = `${exec_prefix}/bin/innconfval -p`;
 foreach my $line (@values) {
-  eval 'our '.$line;
-  if ($line =~ /^(.*?) = /m) {
-    push(@INNCONFVAR, $1);
-  }
+    eval 'our ' . $line;
+    if ($line =~ /^(.*?) = /m) {
+        push(@INNCONFVAR, $1);
+    }
 }
 
-
 ##  Paths of useful directories.
 my @DIRVAR = qw($prefix $exec_prefix $newshome $home $newslib
-$newsbin $controlprogs $newslbin $newsetc $spooldir
-$archivedir $spool $incoming $spoolnews $badnews
-$batch $overviewdir $most_logs $locks $innddir $tmpdir
-$spooltemp $path);
+  $newsbin $controlprogs $newslbin $newsetc $spooldir
+  $archivedir $spool $incoming $spoolnews $badnews
+  $batch $overviewdir $most_logs $locks $innddir $tmpdir
+  $spooltemp $path);
 our $newshome = $pathnews;
 our $home = $pathnews;
 our $newslib = "${exec_prefix}/lib";
@@ -60,9 +54,9 @@ $path = "${newslbin}:${newsbin}:${path}:/bin:/usr/bin";
 
 ##  Paths of useful files.
 my @FILESVAR = qw($active $activetimes $newactive $oldactive
-$history $newsgroups $ctlfile $ctlwatch $localgroups
-$newsfeeds $path_motd_innd $path_motd_nnrpd $path_motd
-$expirectl $errlog $log);
+  $history $newsgroups $ctlfile $ctlwatch $localgroups
+  $newsfeeds $path_motd_innd $path_motd_nnrpd $path_motd
+  $expirectl $errlog $log);
 our $active = "${pathdb}/active";
 our $activetimes = "${pathdb}/active.times";
 our $newactive = "${pathdb}/active.tmp";
@@ -80,12 +74,11 @@ our $expirectl = "${newsetc}/expire.ctl";
 our $errlog = "${most_logs}/errlog";
 our $log = "${most_logs}/news";
 
-
 ##  Paths of useful programs.
 my @PROGVAR = qw($inews $innconfval $innd $inndf $innwatch
-$rnews $perl_startup_innd $perl_filter_innd $perl_filter_nnrpd
-$python_filter_innd $path_python_inn_module $path_tcl_startup
-$path_tcl_filter);
+  $rnews $perl_startup_innd $perl_filter_innd $perl_filter_nnrpd
+  $python_filter_innd $path_python_inn_module $path_tcl_startup
+  $path_tcl_filter);
 our $inews = "${newsbin}/inews";
 our $innconfval = "${newsbin}/innconfval";
 our $innd = "${newsbin}/innd";
@@ -100,10 +93,9 @@ our $path_python_inn_module = "$pathfilter/INN.py";
 our $path_tcl_startup = "$pathfilter/startup.tcl";
 our $path_tcl_filter = "$pathfilter/filter.tcl";
 
-
 ##  Paths of lock/PID/status files.
 my @LOCKVAR = qw($daily $newscontrol $nntpconnect $serverpid
-$innwstatus $watchpid $tempsock $tempsockdir);
+  $innwstatus $watchpid $tempsock $tempsockdir);
 our $daily = "${locks}/LOCK.news.daily";
 our $newscontrol = "${innddir}/control";
 our $nntpconnect = "${innddir}/nntpin";
@@ -113,13 +105,13 @@ our $watchpid = "${innddir}/innwatch.pid";
 (our $tempsock = "${innddir}/ctlinndXXXXXX") =~ s!.*/(.*)XXXXXX$!$1*!;
 (our $tempsockdir = "${innddir}/ctlinndXXXXXX") =~ s!/[^/]*$!!;
 
-
 ##  Paths of external used programs.
-my @EXTPROGVAR = qw($awk $egrep $gpgv $perl $pgp $sed
-$sort $getftp $uustat $uux);
+my @EXTPROGVAR = qw($awk $egrep $gpgv $gpg $perl $pgp $sed
+  $sort $getftp $uustat $uux);
 our $awk = 'gawk';
 our $egrep = '/usr/bin/grep -E';
-our $gpgv = '/usr/bin/gpgv2';
+our $gpgv = '/usr/bin/gpgv';
+our $gpg = '/usr/bin/gpg';
 our $perl = '/usr/bin/perl';
 our $pgp = '';
 our $sed = '/usr/bin/sed';
@@ -128,10 +120,9 @@ our $getftp = "${exec_prefix}/bin/simpleftp";
 our $uustat = '';
 our $uux = 'uux';
 
-
 ##  Paths of external used compressors.
 my @EXTCOMPVAR = qw($bzip2 $compress $gzip $uncompress
-$log_compress $z);
+  $log_compress $z);
 our $bzip2 = '/usr/bin/bzip2';
 our $compress = 'compress';
 our $gzip = '/usr/bin/gzip';
@@ -139,25 +130,28 @@ our $uncompress = '/usr/bin/gzip -d';
 our $log_compress = '/usr/bin/gzip';
 our $z = '.gz';
 
-
 ##  Set up some useful system file information.
 my @SYSVAR = qw($newsmaster $newsuser $newsgroup
-$filemode $inewsmode $rnewsmode $umask $syslog_facility);
+  $filemode $inewsmode $rnewsmode $umask $syslog_facility);
 our $newsmaster = 'usenet';
 our $newsuser = ${runasuser};
 our $newsgroup = ${runasgroup};
-our $filemode = 0664;      # It is a number.
+#<<V  code skipping because perltidy expects numbers.
+our $filemode = 0664;    # It is a number.
 our $inewsmode = 0550;
 our $rnewsmode = 0500;
 our $umask = 02;
+#>>V
 our $syslog_facility = lc('LOG_NEWS');
 $syslog_facility =~ s/log_//;
 
-
 ##  Set up some useful parameters.
-my @PARAMVAR = qw($do_dbz_tagged_hash);
+my @PARAMVAR = qw($do_dbz_tagged_hash $gpg_has_allow_weak_digest_algos_flag);
 our $do_dbz_tagged_hash = 'DONT';
-
+#<<V  code skipping because perltidy expects numbers.
+our $gpg_has_allow_weak_digest_algos_flag
+  = 1;
+#>>V
 
 ##  Set up some environment values.
 if ($ovmethod && $ovmethod eq "ovdb") {
@@ -175,27 +169,26 @@ $ENV{'PATH'} = $path;
 $ENV{'SPOOLDIR'} = $spooldir;
 $ENV{'TMPDIR'} = $pathtmp;
 
-
 ##  Set up the locale.
 $ENV{'LC_CTYPE'} = "C";
 
-
 ##  Set up umask.
+#<<V  code skipping because perltidy expects a number.
 umask 02;
-
+#>>V
 
 ##  This array will contain what it is possible to export.
-our @EXPORT_OK = (@INNCONFVAR, @DIRVAR, @FILESVAR, @PROGVAR,
-@LOCKVAR, @EXTPROGVAR, @EXTCOMPVAR, @SYSVAR, @PARAMVAR,
-qw($VERSION));
-
+our @EXPORT_OK = (
+    @INNCONFVAR, @DIRVAR, @FILESVAR, @PROGVAR,
+    @LOCKVAR, @EXTPROGVAR, @EXTCOMPVAR, @SYSVAR, @PARAMVAR,
+    qw($VERSION)
+);
 
 ##  Load another script that can override or add variables.
 if (-x "${pathetc}/innshellvars.pl.local") {
     do "${pathetc}/innshellvars.pl.local";
 }
 
-
 ##  That's all.
 1;
 
@@ -208,7 +201,7 @@ INN::Config - Export all the variables an INN Perl script might need
 =head1 DESCRIPTION
 
 This Perl module sets up any and all the variables that an INN Perl script
-might need.  More particularly, it allows to use F<inn.conf> variables:
+might need.  More particularly, it allows using F<inn.conf> variables:
 they are all provided by B<innconfval>, as well as the version of INN
 (in the variable C<$INN::Config::VERSION> for its short number form, on in
 C<$INN::Config::version> for its complete form).  Other useful variables
@@ -266,7 +259,7 @@ if you specify what you want to import:
 Note that a legacy F<innshellvars.pl> is also provided in I<pathnews>/lib
 for compatibility reasons with old Perl scripts not shipped with INN.
 It was used by versions of INN anterior to 2.5.0.  The corresponding
-scripts for Shell and Tcl are, however, still in use:  F<innshellvars>
+scripts for Shell and Tcl are, however, still in use: F<innshellvars>
 and F<innshellvars.tcl>.  They offer the same capabilities as this
 module.
 
@@ -276,8 +269,6 @@ F<innshellvars.pl> was written by James Brister <brister@vix.com>
 for InterNetNews in 1996.  It was converted to the INN::Config Perl
 module by Julien Elie in 2007.
 
-$Id: Config.pm.in 9567 2013-11-17 20:24:35Z iulius $
-
 =head1 SEE ALSO
 
 inn.conf(5), innconfval(1), perl(1).
